==> qt-embedded-free-3.3.2.tar.bz2: qt-embedded-free-3.3.2/src/kernel/qscriptengine_qws.cpp <==
/****************************************************************************
** $Id: qt/qscriptengine_qws.cpp   3.3.2   edited Jan 7 11:58 $
**
** The script engine jump table
**
** Copyright (C) 2003 Trolltech AS.  All rights reserved.
**
** This file is part of the kernel module of the Qt GUI Toolkit.
**
** This file may be distributed and/or modified under the terms of the
** GNU General Public License version 2 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.
**
** Licensees holding valid Qt Enterprise Edition or Qt Professional Edition
** licenses for Qt/Embedded may use this file in accordance with the
** Qt Embedded Commercial License Agreement provided with the Software.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
**
** See http://www.trolltech.com/pricing.html or email sales@trolltech.com for
**   information about Qt Commercial License Agreements.
** See http://www.trolltech.com/gpl/ for GPL licensing information.
**
** Contact info@trolltech.com if any conditions of this licensing are
** not clear to you.
**
**********************************************************************/

const q_scriptEngine scriptEngines[] = {
	// Latin,
    { basic_shape, basic_attributes },
	// Greek,
    { basic_shape, basic_attributes },
	// Cyrillic,
    { basic_shape, basic_attributes },
	// Armenian,
    { basic_shape, basic_attributes },
	// Georgian,
    { basic_shape, basic_attributes },
	// Runic,
    { basic_shape, basic_attributes },
	// Ogham,
    { basic_shape, basic_attributes },
	// SpacingModifiers,
    { basic_shape, basic_attributes },
	// CombiningMarks,
    { basic_shape, basic_attributes },

	// // Middle Eastern Scripts
	// Hebrew,
    { basic_shape, basic_attributes },
	// Arabic,
    { arabic_shape, arabic_attributes },
	// Syriac,
    { basic_shape, basic_attributes },
	// Thaana,
    { basic_shape, basic_attributes },

	// // South and Southeast Asian Scripts
	// Devanagari,
    { basic_shape, basic_attributes },
	// Bengali,
    { basic_shape, basic_attributes },
	// Gurmukhi,
    { basic_shape, basic_attributes },
	// Gujarati,
    { basic_shape, basic_attributes },
	// Oriya,
    { basic_shape, basic_attributes },
	// Tamil,
    { basic_shape, basic_attributes },
	// Telugu,
    { basic_shape, basic_attributes },
	// Kannada,
    { basic_shape, basic_attributes },
	// Malayalam,
    { basic_shape, basic_attributes },
	// Sinhala,
    { basic_shape, basic_attributes },
	// Thai,
    { basic_shape, basic_attributes },
	// Lao,
    { basic_shape, basic_attributes },
	// Tibetan,
    { basic_shape, basic_attributes },
	// Myanmar,
    { basic_shape, basic_attributes },
	// Khmer,
    { basic_shape, basic_attributes },

	// // East Asian Scripts
	// Han,
    { basic_shape, basic_attributes },
	// Hiragana,
    { basic_shape, basic_attributes },
	// Katakana,
    { basic_shape, basic_attributes },
	// Hangul,
    { basic_shape, basic_attributes },
	// Bopomofo,
    { basic_shape, basic_attributes },
	// Yi,
    { basic_shape, basic_attributes },

	// // Additional Scripts
	// Ethiopic,
    { basic_shape, basic_attributes },
	// Cherokee,
    { basic_shape, basic_attributes },
	// CanadianAboriginal,
    { basic_shape, basic_attributes },
	// Mongolian,
    { basic_shape, basic_attributes },

	// // Symbols
	// CurrencySymbols,
    { basic_shape, basic_attributes },
	// LetterlikeSymbols,
    { basic_shape, basic_attributes },
	// NumberForms,
    { basic_shape, basic_attributes },
	// MathematicalOperators,
    { basic_shape, basic_attributes },
	// TechnicalSymbols,
    { basic_shape, basic_attributes },
	// GeometricSymbols,
    { basic_shape, basic_attributes },
	// MiscellaneousSymbols,
    { basic_shape, basic_attributes },
	// EnclosedAndSquare,
    { basic_shape, basic_attributes },
	// Braille,
    { basic_shape, basic_attributes },

	// Unicode,
    { basic_shape, basic_attributes },
    //Tagalog,
    { basic_shape, basic_attributes },
    //Hanunoo,
    { basic_shape, basic_attributes },
    //Buhid,
    { basic_shape, basic_attributes },
    //Tagbanwa,
    { basic_shape, basic_attributes },
    // KatakanaHalfWidth
    { basic_shape, basic_attributes },
    // Limbu
    { basic_shape, basic_attributes },
    // TaiLe
    { basic_shape, basic_attributes }
};

==> qt-embedded-free-3.3.7.tar.bz2: qt-embedded-free-3.3.7/src/kernel/qscriptengine_qws.cpp <==
/****************************************************************************
** $Id: qt/qscriptengine_qws.cpp   3.3.7   edited Feb 13 2006 $
**
** The script engine jump table
**
** Copyright (C) 2005 Trolltech AS.  All rights reserved.
**
** This file is part of the kernel module of the Qt GUI Toolkit.
**
** This file may be distributed and/or modified under the terms of the
** GNU General Public License version 2 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.
**
** Licensees holding valid Qt Enterprise Edition or Qt Professional Edition
** licenses for Qt/Embedded may use this file in accordance with the
** Qt Embedded Commercial License Agreement provided with the Software.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
**
** See http://www.trolltech.com/pricing.html or email sales@trolltech.com for
**   information about Qt Commercial License Agreements.
** See http://www.trolltech.com/gpl/ for GPL licensing information.
**
** Contact info@trolltech.com if any conditions of this licensing are
** not clear to you.
**
**********************************************************************/

const q_scriptEngine scriptEngines[] = {
	// Latin,
    { basic_shape, 0 },
	// Greek,
    { basic_shape, 0 },
	// Cyrillic,
    { basic_shape, 0 },
	// Armenian,
    { basic_shape, 0 },
	// Georgian,
    { basic_shape, 0 },
	// Runic,
    { basic_shape, 0 },
	// Ogham,
    { basic_shape, 0 },
	// SpacingModifiers,
    { basic_shape, 0 },
	// CombiningMarks,
    { basic_shape, 0 },

	// // Middle Eastern Scripts
	// Hebrew,
    { hebrew_shape, 0 },
	// Arabic,
    { arabic_shape, 0 },
	// Syriac,
    { basic_shape, 0 },
	// Thaana,
    { basic_shape, 0 },

	// // South and Southeast Asian Scripts
	// Devanagari,
    { basic_shape, 0 },
	// Bengali,
    { basic_shape, 0 },
	// Gurmukhi,
    { basic_shape, 0 },
	// Gujarati,
    { basic_shape, 0 },
	// Oriya,
    { basic_shape, 0 },
	// Tamil,
    { basic_shape, 0 },
	// Telugu,
    { basic_shape, 0 },
	// Kannada,
    { basic_shape, 0 },
	// Malayalam,
    { basic_shape, 0 },
	// Sinhala,
    { basic_shape, 0 },
	// Thai,
    { basic_shape, 0 },
	// Lao,
    { basic_shape, 0 },
	// Tibetan,
    { basic_shape, 0 },
	// Myanmar,
    { basic_shape, 0 },
	// Khmer,
    { basic_shape, 0 },

	// // East Asian Scripts
	// Han,
    { basic_shape, 0 },
	// Hiragana,
    { basic_shape, 0 },
	// Katakana,
    { basic_shape, 0 },
	// Hangul,
    { basic_shape, 0 },
	// Bopomofo,
    { basic_shape, 0 },
	// Yi,
    { basic_shape, 0 },

	// // Additional Scripts
	// Ethiopic,
    { basic_shape, 0 },
	// Cherokee,
    { basic_shape, 0 },
	// CanadianAboriginal,
    { basic_shape, 0 },
	// Mongolian,
    { basic_shape, 0 },

	// // Symbols
	// CurrencySymbols,
    { basic_shape, 0 },
	// LetterlikeSymbols,
    { basic_shape, 0 },
	// NumberForms,
    { basic_shape, 0 },
	// MathematicalOperators,
    { basic_shape, 0 },
	// TechnicalSymbols,
    { basic_shape, 0 },
	// GeometricSymbols,
    { basic_shape, 0 },
	// MiscellaneousSymbols,
    { basic_shape, 0 },
	// EnclosedAndSquare,
    { basic_shape, 0 },
	// Braille,
    { basic_shape, 0 },

	// Unicode,
    { basic_shape, 0 },
    //Tagalog,
    { basic_shape, 0 },
    //Hanunoo,
    { basic_shape, 0 },
    //Buhid,
    { basic_shape, 0 },
    //Tagbanwa,
    { basic_shape, 0 },
    // KatakanaHalfWidth
    { basic_shape, 0 },
    // Limbu
    { basic_shape, 0 },
    // TaiLe
    { basic_shape, 0 }
};
